==> manage-3.1.0-43.jar: management/sqls/sale/report/aode/monthByChargeType.sql <==
select
		 	  f_operate_date f_operate_date,  --日期
		  SUM(case when f_type ='发卡售气' then 1 else 0 end)  f_count_open, --发卡人数
		  SUM(case when f_type ='发卡售气' then f_pregas else 0 end)  f_pregas_open, --发卡气量
		  SUM(case when f_type ='发卡售气' then f_collection else 0 end)  f_collection_open, --发卡金额
		  SUM(case when f_type not in ('补卡','发卡售气','补气','换表')  then 1 else 0 end)  f_count_zg, --再够人数
		  SUM(case when f_type not in ('补卡','发卡售气','补气','换表')  then f_pregas else 0 end)  f_pregas_zg, --再够气量
		  SUM(case when f_type not in ('补卡','发卡售气','补气','换表')  then f_collection else 0 end)  f_collection_zg, --再够金额
		  SUM( case when f_type ='补卡'  then 1 else 0 end)  f_count_bk, --补卡人数
		  SUM(case when f_type ='补卡'  then f_collection else 0 end)  f_collection_bk, --补卡金额
		  SUM(case when f_type ='补气'  then 1 else 0 end)  f_count_bq, --补气人数
		  SUM(case when f_type ='补气'  then f_pregas else 0 end)  f_pregas_bq, --补气气量
		  SUM(case when f_type ='补气'  then f_collection else 0 end)  f_collection_bq, --补气金额
		  SUM(case when f_type ='换表'  then 1 else 0 end)  f_count_hb, --换表人数
		  SUM(case when f_type ='换表'  then f_collection else 0 end)  f_collection_hb, --换表金额
		  COUNT(1) f_count,         --总次数
		  SUM(case when f_type <>'补气' then f_pregas else 0 end) f_pregas,         --总气量
		  SUM(case when f_type <>'补气' then f_collection else 0 end) f_collection       --总金额
 from (
	select
	CONVERT(varchar(100), case when f_operator = '悦生活' then f_write_date else f_operate_date end, 23) f_operate_date,
	f_type ,
	f_zones,
	f_pregas,
	f_collection
	from
	t_sellinggas s
	where   f_state<>'无效' and isnull(f_write_card,'')<>'未写卡'
	and { YeanMouthDate != $$:
        $
        	left(convert(varchar,case when f_operator = '悦生活' then f_write_date else f_operate_date end,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date}'
			and (case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date}'
		$,
		f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}	and {condition}  --传组织
	union all
	SELECT
		CONVERT(varchar(100), f_operate_date, 23) f_operate_date,
		'补卡' f_type ,
		f_zones,
		0 f_pregas,
		f_cardfees f_collection
	FROM
		t_fillcard s
	where  f_state<>'无效'
	and { YeanMouthDate != $$:
        $
        	left(convert(varchar,f_operate_date,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00' and f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00'
		$,
		f_end_operate_date != $$:
		$
			f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}
	and {condition}  --传组织
	union all
	SELECT
		CONVERT(varchar(100), f_operate_date, 23) f_operate_date,
		'换表' f_type ,
		f_zones,
		0 f_pregas,
		f_changemeter_fee f_collection
	FROM
		t_changetables s
	where  f_state<>'无效'
	and  { YeanMouthDate != $$:
        $
        	left(convert(varchar,f_operate_date,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00' and f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00'
		$,
		f_end_operate_date != $$:
		$
			f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}	and {condition}  --传组织
	union all
	SELECT
		CONVERT(varchar(100), case when f_operator = '悦生活' then f_write_date else f_operate_date end, 23) f_operate_date,
		'补气' AS f_type ,
		f_zones,
		f_pregas AS f_pregas,
		f_preamount AS f_collection
	FROM
		t_fillgas s
	where f_state<>'无效'
   	and { YeanMouthDate != $$:
        $
        	left(convert(varchar,case when f_operator = '悦生活' then f_write_date else f_operate_date end,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date} 00:00:00'
			and (case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date} 00:00:00'
		$,
		f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}	and {condition}  --传组织
) xx group by f_operate_date order by f_operate_date

==> manage-3.1.0-44.jar: management/sqls/sale/report/aode/monthByChargeType.sql <==
select   f_payment f_payment,
		 	  f_operate_date f_operate_date,  --日期
		  SUM(case when f_type ='发卡售气' then 1 else 0 end)  f_count_open, --发卡人数
		  SUM(case when f_type ='发卡售气' then f_pregas else 0 end)  f_pregas_open, --发卡气量
		  SUM(case when f_type ='发卡售气' then f_collection else 0 end)  f_collection_open, --发卡金额
		  SUM(case when f_type not in ('补卡','发卡售气','补气','换表')  then 1 else 0 end)  f_count_zg, --再够人数
		  SUM(case when f_type not in ('补卡','发卡售气','补气','换表')  then f_pregas else 0 end)  f_pregas_zg, --再够气量
		  SUM(case when f_type not in ('补卡','发卡售气','补气','换表')  then f_collection else 0 end)  f_collection_zg, --再够金额
		  SUM( case when f_type ='补卡'  then 1 else 0 end)  f_count_bk, --补卡人数
		  SUM(case when f_type ='补卡'  then f_collection else 0 end)  f_collection_bk, --补卡金额
		  SUM(case when f_type ='补气'  then 1 else 0 end)  f_count_bq, --补气人数
		  SUM(case when f_type ='补气'  then f_pregas else 0 end)  f_pregas_bq, --补气气量
		  SUM(case when f_type ='补气'  then f_collection else 0 end)  f_collection_bq, --补气金额
		  SUM(case when f_type ='换表'  then 1 else 0 end)  f_count_hb, --换表人数
		  SUM(case when f_type ='换表'  then f_collection else 0 end)  f_collection_hb, --换表金额
		  COUNT(1) f_count,         --总次数
		  SUM(case when f_type <>'补气' then f_pregas else 0 end) f_pregas,         --总气量
		  SUM(case when f_type <>'补气' then f_collection else 0 end) f_collection       --总金额
 from (
	select
	CONVERT(varchar(100), case when f_operator = '悦生活' then f_write_date else f_operate_date end, 23) f_operate_date,
	f_type ,
	f_zones,
	f_payment,
	f_pregas,
	f_collection
	from
	t_sellinggas s
	where   f_state<>'无效' and isnull(f_write_card,'')<>'未写卡'
	and { YeanMouthDate != $$:
        $
        	left(convert(varchar,case when f_operator = '悦生活' then f_write_date else f_operate_date end,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date}'
			and (case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date}'
		$,
		f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}	and {condition}  --传组织
	union all
	SELECT
		CONVERT(varchar(100), f_operate_date, 23) f_operate_date,
		'补卡' f_type ,
		f_zones,
		f_payment,
		0 f_pregas,
		f_cardfees f_collection
	FROM
		t_fillcard s
	where  f_state<>'无效'
	and { YeanMouthDate != $$:
        $
        	left(convert(varchar,f_operate_date,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00' and f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00'
		$,
		f_end_operate_date != $$:
		$
			f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}
	and {condition}  --传组织
	union all
	SELECT
		CONVERT(varchar(100), f_operate_date, 23) f_operate_date,
		'换表' f_type ,
		f_zones,
		f_payment,
		0 f_pregas,
		f_changemeter_fee f_collection
	FROM
		t_changetables s
	where  f_state<>'无效'
	and  { YeanMouthDate != $$:
        $
        	left(convert(varchar,f_operate_date,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00' and f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			f_operate_date >= '{f_begin_operate_date} 00:00:00'
		$,
		f_end_operate_date != $$:
		$
			f_operate_date <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}	and {condition}  --传组织
	union all
	SELECT
		CONVERT(varchar(100), case when f_operator = '悦生活' then f_write_date else f_operate_date end, 23) f_operate_date,
		'补气' AS f_type ,
		f_zones,
		'' f_payment,
		f_pregas AS f_pregas,
		f_preamount AS f_collection
	FROM
		t_fillgas s
	where f_state<>'无效'
   	and { YeanMouthDate != $$:
        $
        	left(convert(varchar,case when f_operator = '悦生活' then f_write_date else f_operate_date end,21),7)='{YeanMouthDate}'
        $,
        YeanMouthDate == $$:
        $
        	1=1
        $,
        $$
		}
	and { f_begin_operate_date != $$ && f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date} 00:00:00'
			and (case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
		f_begin_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) >= '{f_begin_operate_date} 00:00:00'
		$,
		f_end_operate_date != $$:
		$
			(case when f_operator = '悦生活' then f_write_date else f_operate_date end) <= '{f_end_operate_date} 23:59:59'
		$,
			f_begin_operate_date == $$ && f_end_operate_date == $$:
		$
			1=1
		$,
		$$
	}	and {condition}  --传组织
) xx group by f_operate_date,f_payment order by f_operate_date
